You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by da...@apache.org on 2023/12/22 05:35:46 UTC

(camel) branch main updated: CAMEL-19971: camel-consul - Migrate to a new project that is maintained

This is an automated email from the ASF dual-hosted git repository.

davsclaus pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/camel.git


The following commit(s) were added to refs/heads/main by this push:
     new 5bc7f271402 CAMEL-19971: camel-consul - Migrate to a new project that is maintained
5bc7f271402 is described below

commit 5bc7f27140258f11bbc5e31892a147ddfb5d6587
Author: Claus Ibsen <cl...@gmail.com>
AuthorDate: Fri Dec 22 06:35:34 2023 +0100

    CAMEL-19971: camel-consul - Migrate to a new project that is maintained
---
 .../apache/camel/catalog/components/consul.json    | 12 ++--
 .../dsl/ConsulComponentBuilderFactory.java         | 17 +++---
 .../endpoint/dsl/ConsulEndpointBuilderFactory.java | 66 ++++++++++------------
 3 files changed, 44 insertions(+), 51 deletions(-)

diff --git a/catalog/camel-catalog/src/generated/resources/org/apache/camel/catalog/components/consul.json b/catalog/camel-catalog/src/generated/resources/org/apache/camel/catalog/components/consul.json
index c38a0a352d6..f14cf4e0474 100644
--- a/catalog/camel-catalog/src/generated/resources/org/apache/camel/catalog/components/consul.json
+++ b/catalog/camel-catalog/src/generated/resources/org/apache/camel/catalog/components/consul.json
@@ -23,7 +23,7 @@
   },
   "componentProperties": {
     "connectTimeout": { "index": 0, "kind": "property", "displayName": "Connect Timeout", "group": "common", "label": "", "required": false, "type": "object", "javaType": "java.time.Duration", "deprecated": false, "autowired": false, "secret": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "Connect timeout for OkHttpClient" },
-    "consulClient": { "index": 1, "kind": "property", "displayName": "Consul Client", "group": "common", "label": "common", "required": false, "type": "object", "javaType": "com.orbitz.consul.Consul", "deprecated": false, "autowired": false, "secret": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "Reference to a com.orbitz.consul.Consul in the registry." },
+    "consulClient": { "index": 1, "kind": "property", "displayName": "Consul Client", "group": "common", "label": "common", "required": false, "type": "object", "javaType": "org.kiwiproject.consul.Consul", "deprecated": false, "autowired": false, "secret": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "Reference to a org.kiwiproject.consul.Consul in the registry." },
     "key": { "index": 2, "kind": "property", "displayName": "Key", "group": "common", "label": "", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "autowired": false, "secret": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "The default key. Can be overridden by CamelConsulKey" },
     "pingInstance": { "index": 3, "kind": "property", "displayName": "Ping Instance", "group": "common", "label": "", "required": false, "type": "boolean", "javaType": "boolean", "deprecated": false, "autowired": false, "secret": false, "defaultValue": true, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "Configure if the AgentClient should attempt a ping before returning the Consul instance" },
     "readTimeout": { "index": 4, "kind": "property", "displayName": "Read Timeout", "group": "common", "label": "", "required": false, "type": "object", "javaType": "java.time.Duration", "deprecated": false, "autowired": false, "secret": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "Read timeout for OkHttpClient" },
@@ -36,7 +36,7 @@
     "valueAsString": { "index": 11, "kind": "property", "displayName": "Value As String", "group": "producer", "label": "producer", "required": false, "type": "boolean", "javaType": "boolean", "deprecated": false, "autowired": false, "secret": false, "defaultValue": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "Default to transform values retrieved from Consul i.e. on KV endpoint to string." },
     "autowiredEnabled": { "index": 12, "kind": "property", "displayName": "Autowired Enabled", "group": "advanced", "label": "advanced", "required": false, "type": "boolean", "javaType": "boolean", "deprecated": false, "autowired": false, "secret": false, "defaultValue": true, "description": "Whether autowiring is enabled. This is used for automatic autowiring options (the option must be marked as autowired) by looking up in the registry to find if there is a single instance of matching  [...]
     "configuration": { "index": 13, "kind": "property", "displayName": "Configuration", "group": "advanced", "label": "advanced", "required": false, "type": "object", "javaType": "org.apache.camel.component.consul.ConsulConfiguration", "deprecated": false, "autowired": false, "secret": false, "description": "Consul configuration" },
-    "consistencyMode": { "index": 14, "kind": "property", "displayName": "Consistency Mode", "group": "advanced", "label": "advanced", "required": false, "type": "object", "javaType": "com.orbitz.consul.option.ConsistencyMode", "enum": [ "DEFAULT", "STALE", "CONSISTENT" ], "deprecated": false, "autowired": false, "secret": false, "defaultValue": "DEFAULT", "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description":  [...]
+    "consistencyMode": { "index": 14, "kind": "property", "displayName": "Consistency Mode", "group": "advanced", "label": "advanced", "required": false, "type": "object", "javaType": "org.kiwiproject.consul.option.ConsistencyMode", "enum": [ "DEFAULT", "STALE", "CONSISTENT" ], "deprecated": false, "autowired": false, "secret": false, "defaultValue": "DEFAULT", "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "descripti [...]
     "datacenter": { "index": 15, "kind": "property", "displayName": "Datacenter", "group": "advanced", "label": "advanced", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "autowired": false, "secret": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "The data center" },
     "nearNode": { "index": 16, "kind": "property", "displayName": "Near Node", "group": "advanced", "label": "advanced", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "autowired": false, "secret": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "The near node to use for queries." },
     "nodeMeta": { "index": 17, "kind": "property", "displayName": "Node Meta", "group": "advanced", "label": "advanced", "required": false, "type": "array", "javaType": "java.util.List<java.lang.String>", "deprecated": false, "autowired": false, "secret": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "The note meta-data to use for queries." },
@@ -76,16 +76,16 @@
     "CamelConsulNodeMeta": { "index": 23, "kind": "header", "displayName": "", "group": "producer", "label": "producer", "required": false, "javaType": "List<String>", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The note meta-data to use for queries.", "constantName": "org.apache.camel.component.consul.ConsulConstants#CONSUL_NODE_META" },
     "CamelConsulLastContact": { "index": 24, "kind": "header", "displayName": "", "group": "producer", "label": "producer", "required": false, "javaType": "Long", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The last contact", "constantName": "org.apache.camel.component.consul.ConsulConstants#CONSUL_LAST_CONTACT" },
     "CamelConsulKnownLeader": { "index": 25, "kind": "header", "displayName": "", "group": "producer", "label": "producer", "required": false, "javaType": "Boolean", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "Indicates whether it is the known leader", "constantName": "org.apache.camel.component.consul.ConsulConstants#CONSUL_KNOWN_LEADER" },
-    "CamelConsulConsistencyMode": { "index": 26, "kind": "header", "displayName": "", "group": "producer", "label": "producer", "required": false, "javaType": "com.orbitz.consul.option.ConsistencyMode", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "defaultValue": "DEFAULT", "description": "The consistencyMode used for queries", "constantName": "org.apache.camel.component.consul.ConsulConstants#CONSUL_CONSISTENCY_MODE" },
+    "CamelConsulConsistencyMode": { "index": 26, "kind": "header", "displayName": "", "group": "producer", "label": "producer", "required": false, "javaType": "org.kiwiproject.consul.option.ConsistencyMode", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "defaultValue": "DEFAULT", "description": "The consistencyMode used for queries", "constantName": "org.apache.camel.component.consul.ConsulConstants#CONSUL_CONSISTENCY_MODE" },
     "CamelConsulHealthyOnly": { "index": 27, "kind": "header", "displayName": "", "group": "producer", "label": "producer", "required": false, "javaType": "Boolean", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "defaultValue": "false", "description": "Only on healthy services", "constantName": "org.apache.camel.component.consul.ConsulConstants#CONSUL_HEALTHY_ONLY" },
-    "CamelConsulHealthyState": { "index": 28, "kind": "header", "displayName": "", "group": "producer", "label": "producer", "required": false, "javaType": "com.orbitz.consul.model.State", "enum": [ "PASS", "WARN", "FAIL", "ANY", "UNKNOWN" ], "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The state to query.", "constantName": "org.apache.camel.component.consul.ConsulConstants#CONSUL_HEALTHY_STATE" },
+    "CamelConsulHealthyState": { "index": 28, "kind": "header", "displayName": "", "group": "producer", "label": "producer", "required": false, "javaType": "org.kiwiproject.consul.model.State", "enum": [ "PASS", "WARN", "FAIL", "ANY", "UNKNOWN" ], "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The state to query.", "constantName": "org.apache.camel.component.consul.ConsulConstants#CONSUL_HEALTHY_STATE" },
     "CamelConsulPreparedQueryID": { "index": 29, "kind": "header", "displayName": "", "group": "producer", "label": "producer", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The id of the prepared query", "constantName": "org.apache.camel.component.consul.ConsulConstants#CONSUL_PREPARED_QUERY_ID" },
     "CamelConsulServiceId": { "index": 30, "kind": "header", "displayName": "", "group": "producer", "label": "producer", "required": false, "javaType": "String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The service id for agent deregistration", "constantName": "org.apache.camel.component.consul.ConsulConstants#CONSUL_SERVICE_ID" }
   },
   "properties": {
     "apiEndpoint": { "index": 0, "kind": "path", "displayName": "Api Endpoint", "group": "common", "label": "", "required": true, "type": "string", "javaType": "java.lang.String", "deprecated": false, "deprecationNote": "", "autowired": false, "secret": false, "description": "The API endpoint" },
     "connectTimeout": { "index": 1, "kind": "parameter", "displayName": "Connect Timeout", "group": "common", "label": "", "required": false, "type": "object", "javaType": "java.time.Duration", "deprecated": false, "autowired": false, "secret": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "Connect timeout for OkHttpClient" },
-    "consulClient": { "index": 2, "kind": "parameter", "displayName": "Consul Client", "group": "common", "label": "common", "required": false, "type": "object", "javaType": "com.orbitz.consul.Consul", "deprecated": false, "autowired": false, "secret": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "Reference to a com.orbitz.consul.Consul in the registry." },
+    "consulClient": { "index": 2, "kind": "parameter", "displayName": "Consul Client", "group": "common", "label": "common", "required": false, "type": "object", "javaType": "org.kiwiproject.consul.Consul", "deprecated": false, "autowired": false, "secret": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "Reference to a org.kiwiproject.consul.Consul in the registry." },
     "key": { "index": 3, "kind": "parameter", "displayName": "Key", "group": "common", "label": "", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "autowired": false, "secret": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "The default key. Can be overridden by CamelConsulKey" },
     "pingInstance": { "index": 4, "kind": "parameter", "displayName": "Ping Instance", "group": "common", "label": "", "required": false, "type": "boolean", "javaType": "boolean", "deprecated": false, "autowired": false, "secret": false, "defaultValue": true, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "Configure if the AgentClient should attempt a ping before returning the Consul instance" },
     "readTimeout": { "index": 5, "kind": "parameter", "displayName": "Read Timeout", "group": "common", "label": "", "required": false, "type": "object", "javaType": "java.time.Duration", "deprecated": false, "autowired": false, "secret": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "Read timeout for OkHttpClient" },
@@ -98,7 +98,7 @@
     "action": { "index": 12, "kind": "parameter", "displayName": "Action", "group": "producer", "label": "producer", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "autowired": false, "secret": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "The default action. Can be overridden by CamelConsulAction" },
     "valueAsString": { "index": 13, "kind": "parameter", "displayName": "Value As String", "group": "producer", "label": "producer", "required": false, "type": "boolean", "javaType": "boolean", "deprecated": false, "autowired": false, "secret": false, "defaultValue": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "Default to transform values retrieved from Consul i.e. on KV endpoint to string." },
     "lazyStartProducer": { "index": 14, "kind": "parameter", "displayName": "Lazy Start Producer", "group": "producer (advanced)", "label": "producer,advanced", "required": false, "type": "boolean", "javaType": "boolean", "deprecated": false, "autowired": false, "secret": false, "defaultValue": false, "description": "Whether the producer should be started lazy (on the first message). By starting lazy you can use this to allow CamelContext and routes to startup in situations where a produ [...]
-    "consistencyMode": { "index": 15, "kind": "parameter", "displayName": "Consistency Mode", "group": "advanced", "label": "advanced", "required": false, "type": "object", "javaType": "com.orbitz.consul.option.ConsistencyMode", "enum": [ "DEFAULT", "STALE", "CONSISTENT" ], "deprecated": false, "autowired": false, "secret": false, "defaultValue": "DEFAULT", "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": [...]
+    "consistencyMode": { "index": 15, "kind": "parameter", "displayName": "Consistency Mode", "group": "advanced", "label": "advanced", "required": false, "type": "object", "javaType": "org.kiwiproject.consul.option.ConsistencyMode", "enum": [ "DEFAULT", "STALE", "CONSISTENT" ], "deprecated": false, "autowired": false, "secret": false, "defaultValue": "DEFAULT", "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "descript [...]
     "datacenter": { "index": 16, "kind": "parameter", "displayName": "Datacenter", "group": "advanced", "label": "advanced", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "autowired": false, "secret": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "The data center" },
     "nearNode": { "index": 17, "kind": "parameter", "displayName": "Near Node", "group": "advanced", "label": "advanced", "required": false, "type": "string", "javaType": "java.lang.String", "deprecated": false, "autowired": false, "secret": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "The near node to use for queries." },
     "nodeMeta": { "index": 18, "kind": "parameter", "displayName": "Node Meta", "group": "advanced", "label": "advanced", "required": false, "type": "array", "javaType": "java.util.List<java.lang.String>", "deprecated": false, "autowired": false, "secret": false, "configurationClass": "org.apache.camel.component.consul.ConsulConfiguration", "configurationField": "configuration", "description": "The note meta-data to use for queries." },
diff --git a/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/ConsulComponentBuilderFactory.java b/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/ConsulComponentBuilderFactory.java
index 9c5d2ebef08..9f373b656b3 100644
--- a/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/ConsulComponentBuilderFactory.java
+++ b/dsl/camel-componentdsl/src/generated/java/org/apache/camel/builder/component/dsl/ConsulComponentBuilderFactory.java
@@ -66,10 +66,10 @@ public interface ConsulComponentBuilderFactory {
             return this;
         }
         /**
          * Reference to a com.orbitz.consul.Consul in the registry.
          * 
-         * The option is a: &lt;code&gt;com.orbitz.consul.Consul&lt;/code&gt;
-         * type.
+         * The option is a:
+         * &lt;code&gt;org.kiwiproject.consul.Consul&lt;/code&gt; type.
          * 
          * Group: common
          * 
@@ -77,7 +77,7 @@ public interface ConsulComponentBuilderFactory {
          * @return the dsl builder
          */
         default ConsulComponentBuilder consulClient(
-                com.orbitz.consul.Consul consulClient) {
+                org.kiwiproject.consul.Consul consulClient) {
             doSetProperty("consulClient", consulClient);
             return this;
         }
@@ -291,8 +291,7 @@ public interface ConsulComponentBuilderFactory {
          * ConsistencyMode.DEFAULT.
          * 
          * The option is a:
-         * &lt;code&gt;com.orbitz.consul.option.ConsistencyMode&lt;/code&gt;
-         * type.
+         * &lt;code&gt;org.kiwiproject.consul.option.ConsistencyMode&lt;/code&gt; type.
          * 
          * Default: DEFAULT
          * Group: advanced
@@ -301,7 +300,7 @@ public interface ConsulComponentBuilderFactory {
          * @return the dsl builder
          */
         default ConsulComponentBuilder consistencyMode(
-                com.orbitz.consul.option.ConsistencyMode consistencyMode) {
+                org.kiwiproject.consul.option.ConsistencyMode consistencyMode) {
             doSetProperty("consistencyMode", consistencyMode);
             return this;
         }
@@ -496,7 +495,7 @@ public interface ConsulComponentBuilderFactory {
                 Object value) {
             switch (name) {
             case "connectTimeout": getOrCreateConfiguration((ConsulComponent) component).setConnectTimeout((java.time.Duration) value); return true;
-            case "consulClient": getOrCreateConfiguration((ConsulComponent) component).setConsulClient((com.orbitz.consul.Consul) value); return true;
+            case "consulClient": getOrCreateConfiguration((ConsulComponent) component).setConsulClient((org.kiwiproject.consul.Consul) value); return true;
             case "key": getOrCreateConfiguration((ConsulComponent) component).setKey((java.lang.String) value); return true;
             case "pingInstance": getOrCreateConfiguration((ConsulComponent) component).setPingInstance((boolean) value); return true;
             case "readTimeout": getOrCreateConfiguration((ConsulComponent) component).setReadTimeout((java.time.Duration) value); return true;
@@ -509,7 +508,7 @@ public interface ConsulComponentBuilderFactory {
             case "valueAsString": getOrCreateConfiguration((ConsulComponent) component).setValueAsString((boolean) value); return true;
             case "autowiredEnabled": ((ConsulComponent) component).setAutowiredEnabled((boolean) value); return true;
             case "configuration": ((ConsulComponent) component).setConfiguration((org.apache.camel.component.consul.ConsulConfiguration) value); return true;
-            case "consistencyMode": getOrCreateConfiguration((ConsulComponent) component).setConsistencyMode((com.orbitz.consul.option.ConsistencyMode) value); return true;
+            case "consistencyMode": getOrCreateConfiguration((ConsulComponent) component).setConsistencyMode((org.kiwiproject.consul.option.ConsistencyMode) value); return true;
             case "datacenter": getOrCreateConfiguration((ConsulComponent) component).setDatacenter((java.lang.String) value); return true;
             case "nearNode": getOrCreateConfiguration((ConsulComponent) component).setNearNode((java.lang.String) value); return true;
             case "nodeMeta": getOrCreateConfiguration((ConsulComponent) component).setNodeMeta((java.util.List) value); return true;
@@ -66,10 +66,10 @@ public interface ConsulComponentBuilderFactory {
         }
         /**
-         * Reference to a com.orbitz.consul.Consul in the registry.
+         * Reference to a org.kiwiproject.consul.Consul in the registry.
          * 
diff --git a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/ConsulEndpointBuilderFactory.java b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/ConsulEndpointBuilderFactory.java
index d066b411b93..67fc5eb3412 100644
--- a/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/ConsulEndpointBuilderFactory.java
+++ b/dsl/camel-endpointdsl/src/generated/java/org/apache/camel/builder/endpoint/dsl/ConsulEndpointBuilderFactory.java
@@ -75,10 +75,10 @@ public interface ConsulEndpointBuilderFactory {
             return this;
         }
         /**
          * Reference to a com.orbitz.consul.Consul in the registry.
          * 
-         * The option is a: &lt;code&gt;com.orbitz.consul.Consul&lt;/code&gt;
-         * type.
+         * The option is a:
+         * &lt;code&gt;org.kiwiproject.consul.Consul&lt;/code&gt; type.
          * 
          * Group: common
          * 
@@ -86,15 +86,15 @@ public interface ConsulEndpointBuilderFactory {
          * @return the dsl builder
          */
         default ConsulEndpointConsumerBuilder consulClient(
-                com.orbitz.consul.Consul consulClient) {
+                org.kiwiproject.consul.Consul consulClient) {
             doSetProperty("consulClient", consulClient);
             return this;
         }
         /**
          * Reference to a com.orbitz.consul.Consul in the registry.
          * 
          * The option will be converted to a
-         * &lt;code&gt;com.orbitz.consul.Consul&lt;/code&gt; type.
+         * &lt;code&gt;org.kiwiproject.consul.Consul&lt;/code&gt; type.
          * 
          * Group: common
          * 
@@ -551,8 +551,7 @@ public interface ConsulEndpointBuilderFactory {
          * ConsistencyMode.DEFAULT.
          * 
          * The option is a:
-         * &lt;code&gt;com.orbitz.consul.option.ConsistencyMode&lt;/code&gt;
-         * type.
+         * &lt;code&gt;org.kiwiproject.consul.option.ConsistencyMode&lt;/code&gt; type.
          * 
          * Default: DEFAULT
          * Group: advanced
@@ -561,7 +560,7 @@ public interface ConsulEndpointBuilderFactory {
          * @return the dsl builder
          */
         default AdvancedConsulEndpointConsumerBuilder consistencyMode(
-                com.orbitz.consul.option.ConsistencyMode consistencyMode) {
+                org.kiwiproject.consul.option.ConsistencyMode consistencyMode) {
             doSetProperty("consistencyMode", consistencyMode);
             return this;
         }
@@ -570,8 +569,7 @@ public interface ConsulEndpointBuilderFactory {
          * ConsistencyMode.DEFAULT.
          * 
          * The option will be converted to a
-         * &lt;code&gt;com.orbitz.consul.option.ConsistencyMode&lt;/code&gt;
-         * type.
+         * &lt;code&gt;org.kiwiproject.consul.option.ConsistencyMode&lt;/code&gt; type.
          * 
          * Default: DEFAULT
          * Group: advanced
@@ -687,10 +685,10 @@ public interface ConsulEndpointBuilderFactory {
             return this;
         }
         /**
          * Reference to a com.orbitz.consul.Consul in the registry.
          * 
-         * The option is a: &lt;code&gt;com.orbitz.consul.Consul&lt;/code&gt;
-         * type.
+         * The option is a:
+         * &lt;code&gt;org.kiwiproject.consul.Consul&lt;/code&gt; type.
          * 
          * Group: common
          * 
@@ -698,15 +696,15 @@ public interface ConsulEndpointBuilderFactory {
          * @return the dsl builder
          */
         default ConsulEndpointProducerBuilder consulClient(
-                com.orbitz.consul.Consul consulClient) {
+                org.kiwiproject.consul.Consul consulClient) {
             doSetProperty("consulClient", consulClient);
             return this;
         }
         /**
          * Reference to a com.orbitz.consul.Consul in the registry.
          * 
          * The option will be converted to a
-         * &lt;code&gt;com.orbitz.consul.Consul&lt;/code&gt; type.
+         * &lt;code&gt;org.kiwiproject.consul.Consul&lt;/code&gt; type.
          * 
          * Group: common
          * 
@@ -1041,8 +1039,7 @@ public interface ConsulEndpointBuilderFactory {
          * ConsistencyMode.DEFAULT.
          * 
          * The option is a:
-         * &lt;code&gt;com.orbitz.consul.option.ConsistencyMode&lt;/code&gt;
-         * type.
+         * &lt;code&gt;org.kiwiproject.consul.option.ConsistencyMode&lt;/code&gt; type.
          * 
          * Default: DEFAULT
          * Group: advanced
@@ -1051,7 +1048,7 @@ public interface ConsulEndpointBuilderFactory {
          * @return the dsl builder
          */
         default AdvancedConsulEndpointProducerBuilder consistencyMode(
-                com.orbitz.consul.option.ConsistencyMode consistencyMode) {
+                org.kiwiproject.consul.option.ConsistencyMode consistencyMode) {
             doSetProperty("consistencyMode", consistencyMode);
             return this;
         }
@@ -1060,8 +1057,7 @@ public interface ConsulEndpointBuilderFactory {
          * ConsistencyMode.DEFAULT.
          * 
          * The option will be converted to a
-         * &lt;code&gt;com.orbitz.consul.option.ConsistencyMode&lt;/code&gt;
-         * type.
+         * &lt;code&gt;org.kiwiproject.consul.option.ConsistencyMode&lt;/code&gt; type.
          * 
          * Default: DEFAULT
          * Group: advanced
@@ -1177,10 +1173,10 @@ public interface ConsulEndpointBuilderFactory {
             return this;
         }
         /**
          * Reference to a com.orbitz.consul.Consul in the registry.
          * 
-         * The option is a: &lt;code&gt;com.orbitz.consul.Consul&lt;/code&gt;
-         * type.
+         * The option is a:
+         * &lt;code&gt;org.kiwiproject.consul.Consul&lt;/code&gt; type.
          * 
          * Group: common
          * 
@@ -1188,15 +1184,15 @@ public interface ConsulEndpointBuilderFactory {
          * @return the dsl builder
          */
         default ConsulEndpointBuilder consulClient(
-                com.orbitz.consul.Consul consulClient) {
+                org.kiwiproject.consul.Consul consulClient) {
             doSetProperty("consulClient", consulClient);
             return this;
         }
         /**
          * Reference to a com.orbitz.consul.Consul in the registry.
          * 
          * The option will be converted to a
-         * &lt;code&gt;com.orbitz.consul.Consul&lt;/code&gt; type.
+         * &lt;code&gt;org.kiwiproject.consul.Consul&lt;/code&gt; type.
          * 
          * Group: common
          * 
@@ -1434,8 +1430,7 @@ public interface ConsulEndpointBuilderFactory {
          * ConsistencyMode.DEFAULT.
          * 
          * The option is a:
-         * &lt;code&gt;com.orbitz.consul.option.ConsistencyMode&lt;/code&gt;
-         * type.
+         * &lt;code&gt;org.kiwiproject.consul.option.ConsistencyMode&lt;/code&gt; type.
          * 
          * Default: DEFAULT
          * Group: advanced
@@ -1444,7 +1439,7 @@ public interface ConsulEndpointBuilderFactory {
          * @return the dsl builder
          */
         default AdvancedConsulEndpointBuilder consistencyMode(
-                com.orbitz.consul.option.ConsistencyMode consistencyMode) {
+                org.kiwiproject.consul.option.ConsistencyMode consistencyMode) {
             doSetProperty("consistencyMode", consistencyMode);
             return this;
         }
@@ -1453,8 +1448,7 @@ public interface ConsulEndpointBuilderFactory {
          * ConsistencyMode.DEFAULT.
          * 
          * The option will be converted to a
-         * &lt;code&gt;com.orbitz.consul.option.ConsistencyMode&lt;/code&gt;
-         * type.
+         * &lt;code&gt;org.kiwiproject.consul.option.ConsistencyMode&lt;/code&gt; type.
          * 
          * Default: DEFAULT
          * Group: advanced
@@ -1937,8 +1931,8 @@ public interface ConsulEndpointBuilderFactory {
         /**
          * The consistencyMode used for queries.
          * 
-         * The option is a: {@code com.orbitz.consul.option.ConsistencyMode}
-         * type.
+         * The option is a: {@code
+         * org.kiwiproject.consul.option.ConsistencyMode} type.
          * 
          * Default: DEFAULT
          * Group: producer
@@ -1966,7 +1960,7 @@ public interface ConsulEndpointBuilderFactory {
         /**
          * The state to query.
          * 
          * The option is a: {@code com.orbitz.consul.model.State} type.
          * 
          * Group: producer
          *
@@ -75,10 +75,10 @@ public interface ConsulEndpointBuilderFactory {
         }
         /**
-         * Reference to a com.orbitz.consul.Consul in the registry.
+         * Reference to a org.kiwiproject.consul.Consul in the registry.
          * 
@@ -86,15 +86,15 @@ public interface ConsulEndpointBuilderFactory {
         }
         /**
-         * Reference to a com.orbitz.consul.Consul in the registry.
+         * Reference to a org.kiwiproject.consul.Consul in the registry.
          * 
          * The option will be converted to a
@@ -687,10 +685,10 @@ public interface ConsulEndpointBuilderFactory {
         }
         /**
-         * Reference to a com.orbitz.consul.Consul in the registry.
+         * Reference to a org.kiwiproject.consul.Consul in the registry.
          * 
@@ -698,15 +696,15 @@ public interface ConsulEndpointBuilderFactory {
         }
         /**
-         * Reference to a com.orbitz.consul.Consul in the registry.
+         * Reference to a org.kiwiproject.consul.Consul in the registry.
          * 
          * The option will be converted to a
@@ -1177,10 +1173,10 @@ public interface ConsulEndpointBuilderFactory {
         }
         /**
-         * Reference to a com.orbitz.consul.Consul in the registry.
+         * Reference to a org.kiwiproject.consul.Consul in the registry.
          * 
@@ -1188,15 +1184,15 @@ public interface ConsulEndpointBuilderFactory {
         }
         /**
-         * Reference to a com.orbitz.consul.Consul in the registry.
+         * Reference to a org.kiwiproject.consul.Consul in the registry.
          * 
          * The option will be converted to a
@@ -1966,7 +1960,7 @@ public interface ConsulEndpointBuilderFactory {
          * The state to query.
          * 
-         * The option is a: {@code com.orbitz.consul.model.State} type.
+         * The option is a: {@code org.kiwiproject.consul.model.State} type.
          * 
          * Group: producer